﻿using ComPDFKit.PDFDocument;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BatesTest
{
    internal class BatesTest
    {
        private static string outputPath = Path.GetDirectoryName(Path.GetDirectoryName(Path.GetDirectoryName(System.IO.Directory.GetCurrentDirectory()))) + "\\Output\\Bates";
        
        private static Dictionary<int, string> IntToLocationDic = new Dictionary<int, string>()
        {
            {0, "Top Left" },
            {1, "Top Middle" },
            {2, "Top Right" },
            {3, "Bottom Left" },
            {4, "Bottom Middle" },
            {5, "Bottom Right" }
        };

        static void Main(string[] args)
        {
            Console.WriteLine("Running bates test sample…\r\n");
            SDKLicenseHelper.LicenseVerify();

            CPDFDocument document = CPDFDocument.InitWithFilePath("CommonFivePage.pdf");

            if (!Directory.Exists(outputPath))
            {
                Directory.CreateDirectory(outputPath);
            }

            #region Add bates
            if (AddBates(document))
            {
                Console.WriteLine("Add bates done.");
            }
            else
            {
                Console.WriteLine("Add bates failed.");
            }
            #endregion
            Console.WriteLine("--------------------");

            #region Edit bates
            if (EditBates(document))
            {
                Console.WriteLine("Edit bates done.");
            }
            else
            {
                Console.WriteLine("Edit bates failed.");
            }
            #endregion
            Console.WriteLine("--------------------");

            #region Clear bates
            if (ClearBates(document))
            {
                Console.WriteLine("Clear bates done.");
            }
            else
            {
                Console.WriteLine("Clear bates failed.");
            }
            #endregion
            Console.WriteLine("--------------------");
            Console.WriteLine("Done!");
            Console.WriteLine("--------------------");
             
            Console.ReadLine();
        }

        private static bool AddBates(CPDFDocument document)
        {
            string addBatesPath = outputPath + "\\AddBatesTest.pdf";

            CPDFBates bates = document.GetBates();
            byte[] color = { 255, 0, 0 };
             
            bates.SetPages("0-" + (document.PageCount - 1));

            for (int i = 0; i <= 5; i++)
            {
                bates.SetText(i, @"<<#3#5#Prefix-#-Suffix>>"); 
                bates.SetTextColor(i, color);
                bates.SetFontSize(i, 14);
                 
                Console.WriteLine("Text: {0}", bates.GetText(i));
                Console.WriteLine("Location: {0}\n", IntToLocationDic[i]);
            }

            bates.Update();

            if (document.WriteToFilePath(addBatesPath))
            {
                Console.WriteLine("Browse the changed file in " + addBatesPath);
                return true;
            }
            else
            {
                return false;
            }
        }

        private static bool EditBates(CPDFDocument document)
        {

            CPDFBates bates = document.GetBates();
            if(bates.GetText(0) != string.Empty)
            {
                Console.WriteLine("Get old bates 0 done, text is {0}", bates.GetText(0));
            }
            else
            {
                Console.WriteLine("Get bates 0 failed, or it does not exist");
                return false;
            }

            bates.SetText(0, @"<<#3#1#ComPDFKit-#-ComPDFKit>>");

            bates.Update();
             
            Console.WriteLine("Change bates 0 done, new text is {0}", bates.GetText(0));

            string editBatesPath = outputPath + "\\EditBatesTest.pdf";

            if (document.WriteToFilePath(editBatesPath))
            {
                Console.WriteLine("Browse the changed file in " + editBatesPath);
                return true;
            }
            else
            {
                return false;
            }
        }

        private static bool ClearBates(CPDFDocument document)
        {
            CPDFBates bates = document.GetBates();

            bates.Clear();

            string clearBatesPath = outputPath + "\\ClearBatesTest.pdf";

            if (document.WriteToFilePath(clearBatesPath))
            {
                Console.WriteLine("Browse the changed file in " + clearBatesPath);
                return true;
            }
            else
            {
                return false;
            }
        }
    }
}
